import React, {memo} from 'react';
import {View, TextInput, LayoutChangeEvent} from 'react-native';
import Animated from 'react-native-reanimated';
import {PLACEHOLDER, SIDES} from '../../constants';
import {useRNDTExternal, useRNDTInternal} from '../../hooks';
import styles from './styles';

const CustomTextInput = () => {
  const {boxHeight, textInputLayout, isResize, borderStatus} =
    useRNDTInternal();
  const AnimatedTextInput = Animated.createAnimatedComponent(TextInput);
  const {
    externalTextStyles,
    resizerSnapPoints,
    defaultTextValue,
    placeholder,
    onItemActive,
  } = useRNDTExternal();

  const onLayout = (e: LayoutChangeEvent) => {
    const {height, width} = e.nativeEvent.layout;

    textInputLayout.height = height;
    textInputLayout.width = width;

    if (boxHeight.value > height && resizerSnapPoints?.includes(SIDES.BOTTOM)) {
      boxHeight.value = boxHeight.value;
    } else {
      boxHeight.value = height;
    }
  };

  const activateBorder = () => {
    borderStatus.value = true;
    onItemActive?.();
  };

  return (
    <View
      onLayout={e => (isResize.value ? null : onLayout(e))}
      style={styles.customTextInputStyles}>
      <AnimatedTextInput
        multiline
        returnKeyType="done"
        defaultValue={defaultTextValue}
        scrollEnabled={false}
        spellCheck={false}
        autoCorrect={false}
        onFocus={() => activateBorder()}
        onChange={() => (isResize.value = false)}
        style={[styles.textStyles, externalTextStyles]}
        placeholder={
          placeholder ? placeholder : PLACEHOLDER
        }></AnimatedTextInput>
    </View>
  );
};

export default memo(CustomTextInput);
